@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: streaming-commons
 version: 0.1.15.2
-id: streaming-commons-0.1.15.2-092d722155f2dc7f0b2e7a0dc037f30c
-key: strea_GoMpiLp2i3iDjXqSlsVRMj
+id: streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
+key: strea_0Pv1kz8leJoAmtjyRTUWHG
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/streaming-commons
@@ -28,19 +28,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/streaming-commons-0.1.15.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/streaming-commons-0.1.15.2
-hs-libraries: HSstreaming-commons-0.1.15.2-GoMpiLp2i3iDjXqSlsVRMj
+hs-libraries: HSstreaming-commons-0.1.15.2-0Pv1kz8leJoAmtjyRTUWHG
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
